﻿local Engine, Api, Locale, Settings = unpack(Vendetta)

-- Get an existing element instance.
function Api:GetElement(guid)
	return self.Elements[guid]
end

-- Initializes and registers an element instance.
function Api:RegisterElement(guid, params)
	local settings = params or {}
	if guid == nil or self.Elements[guid] ~= nil then
		return
	end
	if settings.Realm == nil or settings.Realm == "" then
		settings.Realm = Engine.Realm
	end

	local element = {}
	
	local class, _, race, _, gender, name, realm = GetPlayerInfoByGUID(guid)
	if realm == "" then -- An empty string indicates the same realm
		realm = Engine.Realm
	end

	element.Guid = guid
	element.Name = settings.Name or name
	element.Realm = settings.Realm or realm
	element.Class = settings.Class or class
	element.Race = settings.Race or race
	element.Gender = settings.Gender or gender
	element.Rating = settings.Rating or 1
	element.Notes = settings.Notes or ""
	element.Timestamp = time(date("*t"))

	-- Register the element instance
	self.Elements[guid] = element

	-- Updates the last encountered
	element.Encounter = function(self)
		element.Timestamp = time(date("*t"))
	end

	return element
end

-- Unregisters an element instance.
function Api:UnregisterElement(guid)
	self.Elements[guid] = nil
end

-- Unregisters all element instances.
function Api:UnregisterAllElements()
	local elements = Api.Elements
	for guid, element in pairs(elements) do
		self:UnregisterElement(guid)
	end
end